==> hyperkyc_flutter-0.3.0.tar.gz: README.md <==
# hyperkyc_flutter

## Flutter Plugin for HyperKyc GSDK
HyperKyc Flutter SDK can be used to create Global DKYC workflows to capture images of ID cards, photos of the face of the user, and perform other operations like face matches, etc all within itself to ease up integration friction on the client end.
The SDK can be used within Flutter applications and supports all iOS versions from iOS 9, and Android OS versions from Lollipop 5.1 (Android API level 21) to Android 12 (Android API level 31)

## Minimum Requirements

1. Android :
   1. Full migration to AndroidX
   2. `minSdkVersion` >= 21
   3. `compileSdkVersion` >= 31
   4. Minimum Gradle versions
      1. Gradle build tools version - `4.0.0`
2. Gradle wrapper version - `6.1.1`
5. Recommended Gradle versions
   1. Gradle build tools version - `7.0.4`
2. Gradle wrapper version - `7.0.2`
2. iOS :
   1. min iOS SDK version 9
   2. Recommended platform versions :
      1. xCode 13+
      2. Swift 5.5
      3. Cocoapods 1.11.x

## Android Setup

1. Make sure that the minimum SDK version is 21 or higher
2. Enable `multidex`
3. Open `android/build.gradle` file and add the following lines inside `allprojects` function

```groovy
allprojects {  
	 repositories { 
		 google() 
		 mavenCentral() 
		 maven { 
			 url = "s3://hvsdk/android/releases" 
			 credentials(AwsCredentials) { 
				 accessKey = "aws_access_key" // get this from the team 
				 secretKey = "aws_secret_pass"// get this from the team 
			} 
		} 
	}
}  
```  

4. Sync the project

## iOS Setup

1. `cd` to iOS directory and run `pod install`
2. Add Camera Permissions to request the user for camera permissions, add this key-value pair in your application's info.plist file.
   - **Key :** Privacy - Camera Usage Description
   - **Value :** "Access to camera is needed for document and face capture"

## Integrate HyperKyc Flutter SDK

1. Create `HyperKycConfig` instance using `HyperKycConfig.fromAccessToken` (more secure) or `HyperKycConfig.fromAppIdAppKey` (less secure)

 ```dart 
//  Create HyperKycConfig instance using `HyperKycConfig.fromAppIdAppKey` (less secure)
var hyperKycConfig = HyperKycConfig.fromAppIdAppKey(
      appId: <app-id>, //  Get this from Hyperverge team
      appKey: <app-key>, //  Get this from Hyperverge team
      workflowId: <workflow-id>, //  Get workflow-id from Hyperverge dashboard
      transactionId: <transaction-id>,
    );
 ```  
2. Set Custom Inputs (Optional)

```dart
final Map<String, String> customInputs = {
      'key1': 'value1',
      'key2': 'value2',
       ...
    }

hyperKycConfig.setInputs(inputs: customInputs)
```
3. Launch HyperKyc

```dart
//  Launch HyperKyc using launch() function
HyperKycResult hyperKycResult = await HyperKyc.launch(hyperKycConfig: hyperKycConfig); // Please contact Hyperverge team to understand how to process HyperKycResult  
 ```
**Please contact Hyperverge for complete documentation and a properly designed solution specific to your usecase to use HyperKyc SDK to its optimum capacity**

==> hyperkyc_flutter-0.19.0.tar.gz: README.md <==
# hyperkyc_flutter

## Flutter Plugin for HyperKYC SDK
HyperKYC Flutter SDK can be used to create Global DKYC workflows to capture images of ID cards, photos of the face of the user, and perform other operations like face matches, etc all within itself to ease up integration friction on the client end.
The SDK can be used within Flutter applications and supports all iOS versions from iOS 11, and Android OS versions from Lollipop 5.1 (Android API level 21) to Android 13 (Android API level 31)

**Please contact Hyperverge for [complete documentation](https://documentation.hyperverge.co/sdks/flutter/) and a properly designed solution specific to your usecase to use HyperKYC SDK to its optimum capacity**

## Minimum Requirements

1. Android :
   1. Full migration to AndroidX
   2. `minSdkVersion` >= 21
   3. `compileSdkVersion` >= 31
   4. Minimum Gradle versions
      1. Gradle build tools version - `4.0.0`
      2. Gradle wrapper version - `6.1.1`
      3. Recommended Gradle versions
         1. Gradle build tools version - `7.0.4`
      4. Gradle wrapper version - `7.0.2`
2. iOS :
   1. min iOS SDK version `11`
   2. Recommended platform versions :
      1. xCode 13+
      2. Swift 5.5
      3. Cocoapods 1.11.x

## Android Setup

1. Make sure that the minimum SDK version is 21 or higher
2. Enable `multidex`
3. Open `android/build.gradle` file and add the following lines inside `allprojects` function
```groovy
allprojects {  
	 repositories { 
		 google() 
		 mavenCentral() 
		 maven {
            url = "https://s3.ap-south-1.amazonaws.com/hvsdk/android/releases" 
		} 
	}
}  
```

4. Sync the project

## iOS Setup

1. `cd` to iOS directory and run `pod install`
2. Add Camera Permissions to request the user for camera permissions, add this key-value pair in your application's info.plist file.
   - **Key :** Privacy - Camera Usage Description
   - **Value :** "Access to camera is needed for document and face capture"

## Integrate HyperKYC Flutter SDK

1. Create `HyperKycConfig` instance using `HyperKycConfig.fromAccessToken` (more secure) or `HyperKycConfig.fromAppIdAppKey` (less secure)

 ```dart 
//  Create HyperKycConfig instance using `HyperKycConfig.fromAppIdAppKey` (less secure)
var hyperKycConfig = HyperKycConfig.fromAppIdAppKey(
      appId: <app-id>, //  Get this from Hyperverge team
      appKey: <app-key>, //  Get this from Hyperverge team
      workflowId: <workflow-id>, //  Get workflow-id from Hyperverge dashboard
      transactionId: <transaction-id>,
    );
 ```  

2. Set Custom Inputs (Optional)

```dart
final Map<String, String> customInputs = {
      'key1': 'value1',
      'key2': 'value2',
       ...
    }

hyperKycConfig.setInputs(inputs: customInputs)
```

3. Launch HyperKYC

```dart
//  Launch HyperKYC using launch() function
HyperKycResult hyperKycResult = await HyperKyc.launch(hyperKycConfig: hyperKycConfig); // Please contact Hyperverge team to understand how to process HyperKycResult  
 ```
